# -*- coding: utf-8 -*-
import ldapdb.models
import pprint, base64, hashlib, os
from django.db import models
from ldapdb.models.fields import CharField, IntegerField, ListField
from django.db.models.signals import post_save, pre_save
from django.dispatch import receiver
from south.modelsinspector import add_ignored_fields

class LdapUser(ldapdb.models.Model):
    base_dn = "ou=users,o=ILLYSE,l=Villeurbanne,st=RHA,c=FR"
    object_classes = ['inetOrgPerson', 'organizationalPerson', 'person', 'top']

    uid = CharField(db_column='uid', unique=True,max_length=255)
    nick_name = CharField(db_column='cn', unique=True, primary_key=True,max_length=255)
    first_name = CharField(db_column='givenName',max_length=255)
    last_name = CharField(db_column='sn',max_length=255)
    display_name = CharField(db_column='displayName',max_length=255, blank=True)
    password = CharField(db_column='userPassword',max_length=255)

    def __unicode__(self):
        return self.display_name
    
    class Meta:
        managed = False #Indique à South de ne pas gérer ce model

add_ignored_fields(["^ldapdb\.models\.fields"]) #Indique à South de ne pas gérer ce model

class Member(models.Model):

    #TODO : Comment traduire ces valeurs
    MEMBER_TYPE_CHOICES =(('individual','individual'),('corporation','corporation'))
    MEMBER_GENDER_CHOICES = (('male','male'),('female','female'))
    
    type = models.CharField(max_length=11, choices=MEMBER_TYPE_CHOICES, default='individual');
    gender = models.CharField(max_length=6, choices=MEMBER_GENDER_CHOICES);
    first_name = models.CharField(max_length=200);
    last_name = models.CharField(max_length=200);
    ldap_cn = models.CharField(max_length=200, default='');
    organization_name = models.CharField(max_length=200, blank=True);
    email = models.EmailField(max_length=254);
    home_phone_number = models.CharField(max_length=25, blank=True);
    mobile_phone_number = models.CharField(max_length=25, blank=True);
    address = models.TextField();
    postal_code = models.CharField(max_length=15);
    city = models.CharField(max_length=200);
    country = models.CharField(max_length=200);
        
    def __unicode__(self):
        return self.first_name+' '+self.last_name;


class CryptoKey(models.Model):
    
    KEY_TYPE_CHOICES=(('RSA','RSA'),('GPG','GPG'))
    
    type = models.CharField(max_length=3, choices=KEY_TYPE_CHOICES);
    key = models.TextField();
    member = models.ForeignKey('Member');

    def __unicode__(self):
        return self.member.__str__();



@receiver(post_save, sender=Member)
def sync_ldap(sender, instance, created, **kwargs):

    if not created:
        ldap_user = LdapUser.objects.get(pk=instance.ldap_cn)
    if created:
        ldap_user = LdapUser()
        ldap_user.pk = instance.ldap_cn
        ldap_user.uid = instance.ldap_cn
        ldap_user.nick_name = instance.ldap_cn
    
    ldap_user.last_name = instance.last_name
    ldap_user.first_name  = instance.first_name
    # ldap_user.password = instance.password
    ldap_user.save();


#===============================================================================
# @receiver(pre_save, sender = LdapUser)
# def ssha_password(sender, **kwargs):
#     if not kwargs['instance'].password.startswith('{SSHA}'):
#         salt = os.urandom(8).encode('hex')
#         kwargs['instance'].password = '{SSHA}' + base64.b64encode(hashlib.sha1(obj.password + salt).digest() + salt)
#===============================================================================
